==> karot_components-0.0.3.tar.gz: lib/button/karot_button.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/button_style.dart';
import 'package:karot_components/constant/text_style.dart';
import 'package:karot_components/constant/theme.dart';

class KRButton extends StatelessWidget {
  final String text;
  final int backgroundColor;
  final int textColor;
  final bool isFull;
  final bool isDisabled;
  final bool isOutline;
  final bool isBold;
  final KRButtonSize size;
  final VoidCallback? onPress;

  const KRButton({
    Key? key,
    required this.text,
    this.onPress,
    this.isFull = false,
    this.isOutline = false,
    this.isBold = false,  
    this.isDisabled = false,
    this.size = KRButtonSize.large,
    this.backgroundColor = KRTheme.DEFAULT_PRIMARY_COLOR,
    this.textColor = KRTheme.DEFAULT_LIGHT_COLOR,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        style: BStyle.buttonStyle(backgroundColor: backgroundColor, isFull: isFull, isOutline: isOutline, size: size),
        onPressed: isDisabled ? null : onPress,
        child: Text(
          text,
          style: TStyle.buttonText(
            isBold: isBold,
            fontSize: size,
              color: isOutline
                  ? Color(textColor) == Colors.white ? const Color(KRTheme.DEFAULT_PRIMARY_COLOR) : Color(textColor)
                  : const Color(KRTheme.DEFAULT_LIGHT_COLOR)),
        ));
  }
}

==> karot_components-0.0.5.tar.gz: lib/button/karot_button.dart <==
import 'package:flutter/material.dart';
import 'package:karot_components/constant/button_enum.dart';
import 'package:karot_components/constant/button_style.dart';
import 'package:karot_components/constant/text_style.dart';
import 'package:karot_components/constant/theme.dart';

class KRButton extends StatelessWidget {
  final String text;
  final int backgroundColor;
  final int textColor;
  final bool isFull;
  final bool isDisabled;
  final bool isOutline;
  final bool isBold;
  final KRButtonSize size;
  final VoidCallback onPressed;

  const KRButton({
    Key? key,
    required this.text,
    required this.onPressed,
    this.isFull = false,
    this.isOutline = false,
    this.isBold = false,  
    this.isDisabled = false,
    this.size = KRButtonSize.large,
    this.backgroundColor = KRTheme.DEFAULT_PRIMARY_COLOR,
    this.textColor = KRTheme.DEFAULT_LIGHT_COLOR,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return TextButton(
        style: BStyle.buttonStyle(backgroundColor: backgroundColor, isFull: isFull, isOutline: isOutline, size: size),
        onPressed: isDisabled ? null : onPressed,
        child: Text(
          text,
          style: TStyle.buttonText(
            isBold: isBold,
            fontSize: size,
              color: isOutline
                  ? Color(textColor) == Colors.white ? const Color(KRTheme.DEFAULT_PRIMARY_COLOR) : Color(textColor)
                  : const Color(KRTheme.DEFAULT_LIGHT_COLOR)),
        )
        
        );
  }
}
